@@ -7,5 +7,7 @@ function(groups, dist) {
     grp.ids<-which(groups==i)
     finals<-rbind(finals,colSums(wts[grp.ids,])/length(grp.ids))
   }
+  colnames(finals)<-levels(as.factor(groups))
+  rownames(finals)<-levels(as.factor(groups))
   return(finals)
 }
